package javax.swing.plaf.metal;

import javax.swing.ButtonModel;
import javax.swing.JCheckBox;
import java.awt.Graphics;
import java.awt.Component;
import java.io.Serializable;
import javax.swing.plaf.UIResource;
import javax.swing.Icon;

public class MetalCheckBoxIcon implements Icon, UIResource, Serializable
{
    public MetalCheckBoxIcon() {
    }
    
    protected int getControlSize() {
        return 13;
    }
    
    @Override
    public void paintIcon(Component component, Graphics graphics, int x, int n) {
        JCheckBox checkBox = (JCheckBox)component;
        ButtonModel model = checkBox.getModel();
        int controlSize = this.getControlSize();
        int selected = model.isSelected();
        if (model.isEnabled()) {
            if (checkBox.isBorderPaintedFlat()) {
                graphics.setColor(MetalLookAndFeel.getControlDarkShadow());
                graphics.drawRect(x + 1, n, controlSize - 1, controlSize - 1);
            }
            if (model.isPressed() && model.isArmed()) {
                if (checkBox.isBorderPaintedFlat()) {
                    graphics.setColor(MetalLookAndFeel.getControlShadow());
                    graphics.fillRect(x + 2, n + 1, controlSize - 2, controlSize - 2);
                }
                else {
                    graphics.setColor(MetalLookAndFeel.getControlShadow());
                    graphics.fillRect(x, n, controlSize - 1, controlSize - 1);
                    MetalUtils.drawPressed3DBorder(graphics, x, n, controlSize, controlSize);
                }
            }
            else if (!checkBox.isBorderPaintedFlat()) {
                MetalUtils.drawFlush3DBorder(graphics, x, n, controlSize, controlSize);
            }
            graphics.setColor(MetalLookAndFeel.getControlInfo());
        }
        else {
            graphics.setColor(MetalLookAndFeel.getControlShadow());
            graphics.drawRect(x, n, controlSize - 1, controlSize - 1);
        }
        if (!(selected == 0)) {
            if (checkBox.isBorderPaintedFlat()) {
                ++x;
            }
            this.drawCheck(component, graphics, x, n);
        }
    }
    
    protected void drawCheck(Component component, Graphics graphics, int n, int n2) {
        int controlSize = this.getControlSize();
        graphics.fillRect(n + 3, n2 + 5, 2, controlSize - 8);
        graphics.drawLine(n + (controlSize - 4), n2 + 3, n + 5, n2 + (controlSize - 6));
        graphics.drawLine(n + (controlSize - 4), n2 + 4, n + 5, n2 + (controlSize - 5));
    }
    
    @Override
    public int getIconWidth() {
        return this.getControlSize();
    }
    
    @Override
    public int getIconHeight() {
        return this.getControlSize();
    }
}
